@@ -74,11 +74,11 @@ int               movie_width  = 320;
 int               movie_height = 180;
 int               ffctv_width  = 320;
 int               ffctv_height = 180;
-float             movie_aspect = 0;
-AVFormatContext   *pFormatCtx;
+float             movie_aspect = 320.0 / 180.0;
+AVFormatContext   *pFormatCtx = NULL;
 int               videoStream = -1;
-AVCodecContext    *pCodecCtx;
-AVFrame           *pFrame;
+AVCodecContext    *pCodecCtx = NULL;
+AVFrame           *pFrame = NULL;
 AVFrame           *pFrameFMT = NULL;
 uint8_t           *buffer = NULL;
 
@@ -143,7 +143,7 @@ int jack_clkconvert =1; /* --jackfps  - NOT YET IMPLEMENTED
                           [0:audio_frames_per_video_frame
                            1:video-file] */
 int use_jack = 1;
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 int use_ltc = 0;        /* -l , --ltc */
 #endif 
 char *load_rc = NULL;
@@ -227,16 +227,12 @@ static struct option const long_options[] =
   {"dropframes", no_argument, 0, 'N'},
   {"nodropframes", no_argument, 0, 'n'},
   {"letterbox", no_argument, 0, 'b'},
-#ifdef HAVE_MIDI
   {"midi", required_argument, 0, 'm'},
   {"midifps", required_argument, 0, 'M'},
   {"midi-driver", required_argument, 0, 'd'},
   {"midiclk", no_argument, 0, 'C'},
   {"no-midiclk", no_argument, 0, 'c'},
-#endif
-#ifdef HAVE_LTCSMPTE
   {"ltc", no_argument, 0, 'l'},
-#endif
 #ifdef JACK_SESSION
   {"uuid", required_argument, 0, 'U'},
   {"rc", required_argument, 0, 'r'},
@@ -278,16 +274,12 @@ decode_switches (int argc, char **argv)
 			   "s"	/* start in full-screen mode */
 			   "i:"	/* info - OSD-mode */
 			   "b"	/* letterbox */
-#ifdef HAVE_MIDI
 			   "m:"	/* midi interface */
 			   "M:"	/* midi clk convert */
 			   "d:"	/* midi driver */
 			   "C"	/* --midiclk */
 			   "c"	/* --no-midiclk */
-#endif
-#ifdef HAVE_LTCSMPTE
 			   "l"	/* --ltc */
-#endif
 #ifdef JACK_SESSION
 			   "r:"	/* --rc */
 			   "U:"	/* --uuid */
@@ -416,11 +408,23 @@ decode_switches (int argc, char **argv)
 	case 'c':		/* --no-midiclk */
           midi_clkadj = 0;
 	  break;
+#else
+	case 'm':		/* --midi */
+	case 'd':		/* --midi-driver */
+	case 'M':		/* --midifps */
+	case 'C':		/* --midiclk */
+	case 'c':		/* --no-midiclk */
+	  printf("This version of xjadeo is compiled without MIDI support\n");
+	  break;
 #endif
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 	case 'l':		/* --ltc */
           use_ltc = 1;
 	  break;
+#else
+	case 'l':		/* --ltc */
+	  printf("This version of xjadeo is compiled without LTC support\n");
+	  break;
 #endif
 	case 'U':		/* --uuid */
 #ifdef JACK_SESSION
@@ -468,15 +472,11 @@ jack video monitor\n", program_name);
 "  -a, --ontop               stack xjadeo window on top of the desktop.\n"
 "                            requires x11 or xv videomode and EWMH.\n"
 "  -b, --letterbox           retain apect ratio when scaling (Xv only).\n"
-#ifdef HAVE_MIDI
 "  -c, --no-midiclk          ignore MTC quarter frames.\n"
-#endif
-#ifdef HAVE_MIDI
 "  -d <name>,                specify midi-driver to use. run 'xjadeo -V' to\n"
 "     --midi-driver <name>   list supported driver(s). <name> is not case-\n"
 "                            sensitive and can be shortened to the first unique\n"
 "                            name. eg '-d j' for jack, '-d alsa-r' for alsa-raw\n"
-#endif
 "  -f <val>, --fps <val>     display update freq. - default -1 use file's fps\n"
 "  -i <int>, --info <int>    render OnScreenDisplay info: 0:off, %i:frame,\n"
 "                            %i:smpte, %i:both. (use remote ctrl for more opts.)\n"
@@ -492,13 +492,10 @@ jack video monitor\n", program_name);
 "  --lash-no-autoresume      [liblash option]\n"
 "  --lash-no-start-server    [liblash option]\n"
 #endif /* HAVE_LASH */
-#ifdef HAVE_LTCSMPTE
 "  -l, --ltc                 sync to LinearTimeCode (audio-jack).\n"
-#endif
 #ifdef JACK_SESSION
 "  -U, --uuid                specify JACK-SESSION UUID.\n"
 #endif
-#ifdef HAVE_MIDI
 "  -m <port>,                use MTC instead of jack-transport\n"
 "      --midi <port>         <port> argument is driver-specific:\n"
 "                            * jack-midi: specify midi-port name to connect to\n"
@@ -514,7 +511,6 @@ jack video monitor\n", program_name);
 "      --midifps <int>       0: use framerate of MTC clock (default)\n" 
 "                            2: use video file FPS\n" 
 "                            3: \"resample\": videoFPS / MTC \n" 
-#endif /* HAVE_MIDI */
 /* - undocumented /hidden/ options
 "  -n , --nodropframes       parse MTC as announced, but do not use frame-drop\n" 
 "                            algorithm for OSD - useful for debugging\n"
@@ -565,7 +561,7 @@ static void printversion (void) {
 #ifdef HAVE_LASH
   printf("LASH ");
 #endif 
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
   printf("LTC ");
 #endif
 #ifdef JACK_SESSION
@@ -666,7 +662,7 @@ void clean_up (int status) {
   if (midi_connected()) midi_close(); 
   else
 #endif
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
   if (ltcjack_connected()) close_ltcjack(); 
   else
 #endif
@@ -746,7 +742,7 @@ main (int argc, char **argv)
   if (videomode < 0) vidoutmode(videomode); // dump modes and exit.
 
   if ((i+1)== argc) movie = argv[i];
-  else if ((remote_en || mq_en || ipc_queue || load_rc) && i==argc) movie = "";
+  else if ((remote_en || mq_en || ipc_queue || osc_port || load_rc) && i==argc) movie = "";
 #ifndef HAVE_MACOSX
   else usage (EXIT_FAILURE);
 #else
@@ -808,7 +804,7 @@ main (int argc, char **argv)
                 if (midi_connected()) midi_close(); 
                 else
 #endif
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
                 if (ltcjack_connected()) close_ltcjack(); 
                 else
 #endif
@@ -835,7 +831,7 @@ main (int argc, char **argv)
     midi_open(midiid);
   } else 
 #endif
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
   if (use_ltc) {
     open_ltcjack(NULL);
   } else
