@@ -153,7 +153,7 @@ void xapi_open(void *d) {
 	if ( open_movie(fn)) 
 		remote_printf(403, "failed to open file '%s'",fn);
 	else	remote_printf(129, "opened file: '%s'",fn);
-        init_moviebuffer();
+	init_moviebuffer();
 	newsourcebuffer();
 	force_redraw=1;
 	//display_frame((int64_t)(dispFrame),1); // update screen
@@ -533,7 +533,7 @@ void xapi_ltc_status(void *d) {
 }
 
 void xapi_open_ltc(void *d) {
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 #ifdef HAVE_MIDI
 	midi_close();
 #endif
@@ -549,7 +549,7 @@ void xapi_open_ltc(void *d) {
 }
 
 void xapi_close_ltc(void *d) {
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 	close_ltcjack();
 	remote_printf(100,"closed ltc-jack connection");
 #else
@@ -561,7 +561,7 @@ void xapi_open_jack(void *d) {
 #ifdef HAVE_MIDI
 	midi_close();
 #endif
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 	close_ltcjack();
 #endif
 	open_jack();
@@ -677,7 +677,7 @@ void xapi_posd(void *d) {
 
 void xapi_psync(void *d) {
 	int ss =0;
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 	if (ltcjack_connected()) ss=3;
 	else
 #endif
@@ -1107,6 +1107,10 @@ int remote_read_io(void) {
 	return(rx>0?0:-1);
 }
 
+void exec_remote_cmd (char *cmd) {
+	exec_remote_cmd_recursive(cmd_root, cmd);
+}
+
 #ifdef HAVE_WINDOWS
 int remote_read_h(void) {
 	int rv=-1;
