@@ -84,7 +84,7 @@ extern int	mq_en;
 extern char	*ipc_queue;
 extern double	delay;
 extern int	seekflags;
-#ifdef HAVE_LTCSMPTE
+#if defined (HAVE_LTCSMPTE) || defined (HAVE_LTC)
 extern int  use_ltc;
 #endif
 
@@ -102,6 +102,8 @@ extern int	OSD_mode;
 const AVRational c1_Q = { 1, 1 };
 double 		tpf = 1.0; /* pts/dts increments per video-frame - cached value */
 
+static int      fFirstTime=1;
+
 #ifdef JACK_SESSION
 extern int jack_session_restore;
 extern int js_winx;
@@ -144,6 +146,9 @@ int select_sleep (int usec) {
 	if (ipc_queue) {
 		if (!remote_read_ipc()) remote_activity=1;
 	}
+#endif
+#ifdef HAVE_LIBLO
+	remote_activity |= process_osc();
 #endif
 	if (remote_activity) {
 	  tv.tv_sec = 0; tv.tv_usec = 1;
@@ -194,7 +199,7 @@ void event_loop(void) {
 		if (midi_connected()) newFrame = midi_poll_frame();
 		else
 #endif
-#ifdef HAVE_LTCSMPTE
+#if (defined HAVE_LTCSMPTE || defined HAVE_LTC)
 		if (ltcjack_connected()) newFrame = ltc_poll_frame();
 		else
 #endif
@@ -324,9 +329,11 @@ int open_movie(char* file_name) {
 		close_movie();
 	}
 
+	fFirstTime = 1;
 	pFrameFMT = NULL;
 	movie_width  = 320;
 	movie_height = 180;
+	movie_aspect = (float)movie_width / (float) movie_height;
 	duration = frames = 1;
 	framerate = 10; // prevent slow reaction to remote-ctl (event loop).
 	file_frame_offset = 0;
@@ -344,6 +351,7 @@ int open_movie(char* file_name) {
 	{
 		if (!remote_en && !mq_en && !ipc_queue) //TODO prevent msg only when starting up with no file...
 			fprintf( stderr, "Cannot open video file %s\n", file_name);
+		pFormatCtx=NULL;
 		return (-1);
 	}
 
@@ -351,6 +359,7 @@ int open_movie(char* file_name) {
 	if(avformat_find_stream_info(pFormatCtx, NULL)<0) {
 		fprintf( stderr, "Cannot find stream information in file %s\n", file_name);
 		avformat_close_input(&pFormatCtx);
+		pFormatCtx=NULL;
 		return (-1);
 	}
 
@@ -375,6 +384,7 @@ int open_movie(char* file_name) {
 	if(videoStream==-1) {
 		fprintf( stderr, "Cannot find a video stream in file %s\n", file_name);
 		avformat_close_input(&pFormatCtx);
+		pFormatCtx=NULL;
 		return( -1 );
 	}
 
@@ -453,6 +463,7 @@ int open_movie(char* file_name) {
 	movie_height = pCodecCtx->height;
 #endif
 
+	movie_aspect = 0;
 	if (movie_aspect<=0.0) {
 		if (av_stream->sample_aspect_ratio.num)
 			movie_aspect = av_q2d(av_stream->sample_aspect_ratio);
@@ -487,6 +498,8 @@ int open_movie(char* file_name) {
 	if(pCodec==NULL) {
 		fprintf( stderr, "Cannot find a codec for file: %s\n", file_name);
 		avformat_close_input(&pFormatCtx);
+		pFormatCtx = NULL;
+		pCodecCtx = NULL;
 		return( -1 );
 	}
 
@@ -494,6 +507,8 @@ int open_movie(char* file_name) {
 	if(avcodec_open2(pCodecCtx, pCodec, NULL)<0) {
 		fprintf( stderr, "Cannot open the codec for file %s\n", file_name);
 		avformat_close_input(&pFormatCtx);
+		pFormatCtx = NULL;
+		pCodecCtx = NULL;
 		return( -1 );
 	}
 
@@ -502,6 +517,8 @@ int open_movie(char* file_name) {
 		fprintf( stderr, "Cannot allocate video frame buffer\n");
 		avcodec_close(pCodecCtx);
 		avformat_close_input(&pFormatCtx);
+		pFormatCtx = NULL;
+		pCodecCtx = NULL;
 		return(-1);
 	}
 
@@ -511,6 +528,8 @@ int open_movie(char* file_name) {
 		av_free(pFrame);
 		avcodec_close(pCodecCtx);
 		avformat_close_input(&pFormatCtx);
+		pFormatCtx = NULL;
+		pCodecCtx = NULL;
 		return(-1);
 	}
 
@@ -538,6 +557,7 @@ void override_fps (double fps) {
 int64_t my_avprev = 0; // last recent seeked timestamp
 
 void render_empty_frame(int blit) {
+	if (!buffer) return;
 	// clear image (black / or YUV green)
 	if (render_fmt == PIX_FMT_UYVY422) {
 		int i;
@@ -715,10 +735,10 @@ read_frame:
 	if (seekflags!=SEEK_CONTINUOUS) return (1);
 
 #ifdef FFDEBUG
-	printf("\nDEBUG: got pts=%li dts:%li frame:%g/%g    ##\n", 
+	printf("\nDEBUG: got pts=%li dts:%li frame: p:%g d:%g    ##\n",
 		(long int) packet->pts , (long int) packet->dts,
-		packet->dts*av_q2d(v_stream->time_base)*framerate,
-		packet->pts*av_q2d(v_stream->time_base)*framerate);
+		packet->pts*framerate*av_q2d(v_stream->time_base),
+		packet->dts*framerate*av_q2d(v_stream->time_base));
 #endif
 	mtsb = packet->pts;  
 
@@ -738,7 +758,12 @@ read_frame:
 	if (mtsb == timestamp) printf("Right.\n");
 #endif
 
-	if (mtsb >= timestamp) return (1); // ok!
+#if 1
+	if (mtsb >= timestamp)
+#else // test & check time-base/ framerate re-scaling
+	if ((mtsb*framerate*av_q2d(v_stream->time_base)) >= (timestamp*framerate*av_q2d(v_stream->time_base)))
+#endif
+		return (1); // ok!
 
 	/* skip to next frame */
 #ifdef FFDEBUG
@@ -768,9 +793,10 @@ read_frame:
 
 void display_frame(int64_t timestamp, int force_update, int do_render) {
 	static AVPacket packet;
-	static int      fFirstTime=1;
 	int             frameFinished;
 
+	if (!buffer || !current_file) { return; }
+
 	if (timestamp - file_frame_offset< 0) timestamp=0;
 	else if(timestamp - file_frame_offset>= frames) timestamp = frames - 1;
 
@@ -782,33 +808,16 @@ void display_frame(int64_t timestamp, int force_update, int do_render) {
 	dispFrame = timestamp;
 	if (OSD_mode&OSD_FRAME) 
 		snprintf(OSD_frame,48,"Frame: %li", dispFrame);
-	if (OSD_mode&OSD_SMPTE) frame_to_smptestring(OSD_smpte,dispFrame);
+	if (OSD_mode&OSD_SMPTE) frame_to_smptestring(OSD_smpte,dispFrame - ts_offset);
 
 	if(fFirstTime) {
 		fFirstTime=0;
-		packet.data=NULL;
+		memset(&packet, 0, sizeof(AVPacket));
 	}
 
 	if (pFrameFMT && my_seek_frame(&packet, timestamp)) {
-		#if 0
-		AVStream *v_stream = pFormatCtx->streams[videoStream];
-		long int myts = (packet.pts==AV_NOPTS_VALUE)?packet.dts:packet.pts;
-		long int myf = (long int) (myts*av_q2d(v_stream->time_base)*framerate);
-		if(want_verbose && myf != dispFrame) //< TODO: make it want_debug 
-			fprintf(stdout, "\t\t\t\tdecoder:%07li  \r", myf);
-		#endif
 		/* Decode video frame */
 		while (1) {
-		#if 0
-			if (packet.pts> 0 && OSD_mode&OSD_FRAME) {
-				myts = (packet.pts==AV_NOPTS_VALUE)?packet.dts:packet.pts;
-				myf = (long int) (myts*av_q2d(v_stream->time_base)*framerate);
-				if (want_ignstart)  // timestamps in the file start counting at ..->start_time 
-					myf-= (long int) ( framerate*(pFormatCtx->start_time/ (double) AV_TIME_BASE));
-				if (myf != dispFrame) 
-					snprintf(OSD_frame,49,"Frame: %li[%li]", dispFrame, myf);
-			}
-		#endif
 			frameFinished=0;	
 			if(packet.stream_index==videoStream) 
 #if LIBAVCODEC_VERSION_MAJOR < 52 || ( LIBAVCODEC_VERSION_MAJOR == 52 && LIBAVCODEC_VERSION_MINOR < 21)
@@ -882,6 +891,8 @@ int close_movie() {
 	//Close the video file
 	avformat_close_input(&pFormatCtx);
 	duration = frames = 1;
+	pCodecCtx = NULL;
+	pFormatCtx = NULL;
 	framerate = 10; // prevent slow reaction to remote-ctl (event loop).
 	return (0);
 }
