@@ -63,9 +63,8 @@ enum { OSD_LEFT=-1, OSD_CENTER=-2, OSD_RIGHT=-3 }; ///< use positive values as p
 
 /* define maximum size for OSD in pixel */
 #ifdef HAVE_FT
-# define ST_WIDTH   (1024)
-# define ST_HEIGHT  (30)
-# define ST_PX      (24)
+# define ST_WIDTH   (1920)
+# define ST_HEIGHT  (128)
 #else 
 # define ST_WIDTH   (0)
 # define ST_HEIGHT  (0)
@@ -119,6 +118,7 @@ int Xgetontop (void);
 int Xgetfullscreen (void);
 
 /* remote.c */
+void exec_remote_cmd (char *cmd);
 void close_remote_ctrl (void) ;
 void open_remote_ctrl (void);
 void close_mq_ctrl (void) ;
@@ -151,13 +151,11 @@ void close_jack(void);
 int jack_connected(void);
 
 /* ltc-jack.c function prototypes */
-#ifdef HAVE_LTCSMPTE
 long ltc_poll_frame (void);
 void open_ltcjack(char *autoconnect);
 void close_ltcjack(void);
 int ltcjack_connected(void);
 const char *ltc_jack_client_name();
-#endif 
 
 /* smpte.c prototypes */
 long int smptestring_to_frame (char *str);
@@ -177,6 +175,7 @@ int midi_choose_driver(char *);
 /* xjosc.c */
 int initialize_osc(int osc_port);
 void shutdown_osc(void);
+int process_osc(void);
 
 /* configfile.c */
 void xjadeorc (void);
@@ -185,5 +184,5 @@ int saveconfig (const char *filename);
 int readconfig (char *fn);
 
 /* freetype - On screen display */
-int render_font (char *fontfile, char *text);
+int render_font (char *fontfile, char *text, int px);
 
